import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import aws_cdk._jsii
import aws_cdk.aws_glue_alpha._jsii
import aws_cdk.aws_kinesisfirehose_alpha._jsii
import aws_cdk.aws_kinesisfirehose_destinations_alpha._jsii
import aws_cdk.integ_tests_alpha._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "aws-ddk-core", "1.2.0", __name__[0:-6], "aws-ddk-core@1.2.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
